(Unfortunately the sourceforge mail archive doesn't include complete 
sender addresses, so I can't copy this message to Peter De Schrijver.)

On 31 Mar 2003, Chris Worley wrote:

> [I didn't see this in the archives from Sunday; I apologize if this is a
> repost; if there is a more appropriate place to post, please tell me]
> 
> On 2003-02-05 21:23:43 Peter 'p2' De Schrijver wrote:
> > Hi,
> > 
> > I'm trying to get the Ego Technology MD100 to work under linux. It's
> > small MP3 player gadget which has 128MB of flash and a USB interface.
> It
> > identifies itself as a USB storage device. When I try to read from it
> > under linux, the process doing the read just hangs. The device works
> > under windows 2000 with the default windows USB storage driver. 
> > I'm running the stock 2.4.20 linux kernel. 
> > 
> > attached is the dmesg output, the output of /proc/bus/usb/devices and
> > .config of the kernel.
> > <...snip a few thousand lines...>
> 
> Peter,
> 
> Did you ever get an answer?  Were you able to get this working?
> 
> I have the same device, although it's marketed differently (claiming
> Linux 2.4.x compatibility!) as a "PowerColor MD100 128MB Portable
> Storage/Music DISK USB MP3 Player":
> 
> http://www.ateck.com/viewItem.asp?idProduct=453055232
> 
> From the vendor "power-color.com":
> 
> http://www.power-color.com/html/md100.html
> 
> But, it has the same USB device/product ID's as yours (0x8341/0x2000).
> 
> Furthermore, I have the exact same problem.  I've tried it on 5
> different Linux Boxes, ranging from SuSE 7.3 to 8.1 and RedHat 7.2 to
> 7.3.  The kernels range from 2.4.9 to 2.4.20; all have USB properly
> installed and working for other devices, including other pen drives.
> 
> The SuSE based machines hang tight (need to power cycle) about a minute
> after installation of the device.  On the RedHat machines, they see the
> device, but any attempt to read the device (i.e. "fdisk -l", "dd
> if=/dev/sda of=/dev/null", "mount /dev/sda ...") locks up the process
> and either the usb-storage or the sd_mod driver (I don't know which).
> 
> Peter's information, at:
> 
>  http://sourceforge.net/mailarchive/message.php?msg_id=3737890
> 
> ...was much more in-depth, but I'll add:
> 

Judging from the information in Peter's message, it looks like the problem 
stems from the use of a START-STOP command.  The patch below removes that 
command; it's a backport from 2.5.  It applies to 2.4.21-pre6.  Try it and 
let me know if it helps.

Alan Stern


--- linux-2.4.21/drivers/scsi/sd.c.orig Mon Mar 31 16:27:31 2003
+++ linux-2.4.21/drivers/scsi/sd.c      Mon Mar 31 16:56:20 2003
@@ -731,15 +731,17 @@
                                 * check_disk_change */
        }
 
        /* Using Start/Stop enables differentiation between drive with
         * no cartridge loaded - NOT READY, drive with changed cartridge -
         * UNIT ATTENTION, or with same cartridge - GOOD STATUS.
-        * This also handles drives that auto spin down. eg iomega jaz 1GB
-        * as this will spin up the drive.
+        *
+        * Drives that auto spin down. eg iomega jaz 1G, will be started
+        * by sd_init_onedisk(), whenever revalidate_scsidisk() is called.
         */
        retval = -ENODEV;
        if (scsi_block_when_processing_errors(SDev))
-               retval = scsi_ioctl(SDev, SCSI_IOCTL_START_UNIT, NULL);
+               retval = scsi_ioctl(SDev, SCSI_IOCTL_TEST_UNIT_READY, NULL);
 
        if (retval) {           /* Unable to test, unit probably not ready.
                                 * This usually means there is no disc in the



-------------------------------------------------------
@@ -731,15 +731,17 @@
        }
 
-       /* Using Start/Stop enables differentiation between drive with
+       /*
+        * Using TEST_UNIT_READY enables differentiation between drive with
         * no cartridge loaded - NOT READY, drive with changed cartridge -
         * UNIT ATTENTION, or with same cartridge - GOOD STATUS.
This SF.net email is sponsored by: ValueWeb: 
Dedicated Hosting for just $79/mo with 500 GB of bandwidth! 
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
_______________________________________________
[EMAIL PROTECTED]
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel

Reply via email to